package net.parsell.cherry.core;

import net.fabricmc.fabric.api.client.rendering.v1.ColorProviderRegistry;
import net.fabricmc.fabric.api.object.builder.v1.block.FabricBlockSettings;
import net.fabricmc.fabric.api.registry.FlammableBlockRegistry;
import net.minecraft.block.Block;
import net.minecraft.block.Blocks;
import net.minecraft.block.LeavesBlock;
import net.minecraft.block.PillarBlock;
import net.minecraft.item.AxeItem;
import net.minecraft.util.Identifier;
import net.minecraft.util.registry.Registry;
import net.parsell.cherry.mixin.AxeItemAccessor;

import java.util.Map;

import com.google.common.collect.ImmutableMap.Builder;

public class CherryBlocks {
	public static final Block CHERRYLOG = registerPillar("cherry_log", FabricBlockSettings.copyOf(Blocks.OAK_LOG), 5, 5);
	public static final Block CHERRYWOOD = registerPillar("cherry_wood", FabricBlockSettings.copyOf(Blocks.OAK_WOOD), 5, 5);
	public static final Block CHERRYLOGSTRIPPED = registerPillar("stripped_cherry_log", FabricBlockSettings.copyOf(Blocks.STRIPPED_OAK_LOG), 5, 5);
	public static final Block CHERRYWOODSTRIPPED = registerPillar("stripped_cherry_wood", FabricBlockSettings.copyOf(Blocks.STRIPPED_OAK_WOOD), 5, 5);
	public static final Block CHERRYLEAVES = registerLeaves("cherry_leaves", FabricBlockSettings.copyOf(Blocks.OAK_LEAVES), 30, 60, 6649929);
	public static final Block CHERRYPLANKS = registerBlock("cherry_planks", FabricBlockSettings.copyOf(Blocks.OAK_PLANKS), 5, 20);

	private static Block registerBlock(String blockID, FabricBlockSettings settings, int burnChance, int burnSpread){
		Block block = new Block(settings);
		Registry.register(Registry.BLOCK, new Identifier("cherry", blockID), block);
		FlammableBlockRegistry.getDefaultInstance().add(block, burnChance, burnSpread);
		return block;
	}

	private static Block registerPillar(String blockID, FabricBlockSettings settings, int burnChance, int burnSpread){
		Block block = new PillarBlock(settings);
		Registry.register(Registry.BLOCK, new Identifier("cherry", blockID), block);
		FlammableBlockRegistry.getDefaultInstance().add(block, burnChance, burnSpread);
		return block;
	}

	private static Block registerLeaves(String blockID, FabricBlockSettings settings, int burnChance, int burnSpread, int color){
		Block block = new LeavesBlock(settings);
		Registry.register(Registry.BLOCK, new Identifier("cherry", blockID), block);
		FlammableBlockRegistry.getDefaultInstance().add(block, burnChance, burnSpread);
		ColorProviderRegistry.BLOCK.register((state, world, pos, tintIndex) -> {
			return color;
		 }, block);
		return block;
	}

	public static void init(){
		// Register unique logs
		Builder<Block, Block> STRIPPED_BLOCKS = new Builder<Block, Block>();
		AxeItemAccessor.getStrippedLogs().forEach((log, strippedLog) -> {
			STRIPPED_BLOCKS.put(log, strippedLog);
		});
		STRIPPED_BLOCKS.put(CHERRYLOG, CHERRYLOGSTRIPPED);
		AxeItemAccessor.setStrippedLogs(STRIPPED_BLOCKS.build());
	}
}
